@@ -19,7 +19,6 @@ X or Y axis for OFC2.
 
 use Moose;
 use Moose::Util::TypeConstraints;
-use MooseX::StrictConstructor;
 
 our $VERSION = '0.01';
 
@@ -29,15 +28,15 @@ use Chart::OFC2::Labels;
 
 =head1 PROPERTIES
 
-    subtype 'Chart.OFC2.YAxis'
+    subtype 'Chart-OFC2-YAxis'
         => as 'Object'
         => where { $_[0]->isa('Chart::OFC2::YAxis') };
-    subtype 'Chart.OFC2.XAxis' 
+    subtype 'Chart-OFC2-XAxis' 
         => as 'Object'
         => where { $_[0]->isa('Chart::OFC2::XAxis') };
 
     has 'name'        => ( is => 'rw', isa => enum(['x_axis', 'y_axis', 'y_axis_right']), required => 1 );
-    has 'labels'      => ( is => 'rw', isa => 'Chart.OFC2.Labels', coerce  => 1);
+    has 'labels'      => ( is => 'rw', isa => 'Chart-OFC2-Labels', coerce  => 1);
     has 'stroke'      => ( is => 'rw', isa => 'Int', );
     has 'colour'      => ( is => 'rw', isa => 'Str',  );
     has 'offset'      => ( is => 'rw', isa => 'Bool', );
@@ -50,28 +49,28 @@ use Chart::OFC2::Labels;
 
 =cut
 
-subtype 'Chart.OFC2.YAxis'
+subtype 'Chart-OFC2-YAxis'
     => as 'Object'
     => where { $_[0]->isa('Chart::OFC2::YAxis') };
-subtype 'Chart.OFC2.XAxis' 
+subtype 'Chart-OFC2-XAxis' 
     => as 'Object'
     => where { $_[0]->isa('Chart::OFC2::XAxis') };
 
-coerce 'Chart.OFC2.XAxis'
+coerce 'Chart-OFC2-XAxis'
     => from 'HashRef'
     => via { Chart::OFC2::XAxis->new($_) };
-coerce 'Chart.OFC2.YAxis'
+coerce 'Chart-OFC2-YAxis'
     => from 'HashRef'
     => via { Chart::OFC2::YAxis->new($_) };
 
 has 'name'        => ( is => 'rw', isa => enum(['x_axis', 'y_axis', 'y_axis_right']), required => 1 );
-has 'labels'      => ( is => 'rw', isa => 'Chart.OFC2.Labels', coerce  => 1);
+has 'labels'      => ( is => 'rw', isa => 'Chart-OFC2-Labels', coerce  => 1);
 has 'stroke'      => ( is => 'rw', isa => 'Int', );
 has 'colour'      => ( is => 'rw', isa => 'Str',  );
 has 'offset'      => ( is => 'rw', isa => 'Bool', );
 has 'grid_colour' => ( is => 'rw', isa => 'Str', );
 has '3d'          => ( is => 'rw', isa => 'Bool', );
-has 'steps'       => ( is => 'rw', isa => 'Chart.OFC2.NaturalInt', );
+has 'steps'       => ( is => 'rw', isa => 'Chart-OFC2-NaturalInt', );
 has 'visible'     => ( is => 'rw', isa => 'Bool',  );
 has 'min'         => ( is => 'rw', isa => 'Num|Str|Undef', );   # can be 'a' for auto too
 has 'max'         => ( is => 'rw', isa => 'Num|Str|Undef', );   # can be 'a' for auto too
@@ -107,7 +106,6 @@ X axis object.
 
 package Chart::OFC2::XAxis;
 use Moose;
-use MooseX::StrictConstructor;
 
 extends 'Chart::OFC2::Axis';
 
@@ -134,7 +132,6 @@ y axis object.
 
 package Chart::OFC2::YAxis;
 use Moose;
-use MooseX::StrictConstructor;
 
 extends 'Chart::OFC2::Axis';
 
@@ -162,7 +159,6 @@ y axis on the right side object.
 package Chart::OFC2::YAxisRight;
 
 use Moose;
-use MooseX::StrictConstructor;
 
 extends 'Chart::OFC2::YAxis';
 
