@@ -22,19 +22,25 @@ our $VERSION = '0.01';
 
 =head1 PROPERTIES
 
-    has 'type_name'    => (is => 'rw', isa => enum(['bar', 'bar_filled', 'pie']), required => 1);
+    has 'type_name'    => (is => 'rw', isa => enum(['bar', 'bar_filled', 'pie', 'hbar']), required => 1);
     has 'values'       => (is => 'rw', isa => 'ArrayRef', trigger => sub { $_[0]->extremes->reset('y' => $_[1]); } );
     has 'extremes'     => (is => 'rw', isa => 'Chart-OFC2-Extremes',  default => sub { Chart::OFC2::Extremes->new() }, lazy => 1);
     has 'use_extremes' => (is => 'rw', isa => 'Bool',  default => 1 );
     has 'on-click'     => (is => 'rw', isa => 'Str', );
+    has 'tip'          => (is => 'rw', isa => 'Str',);
+    has 'alpha'        => (is => 'rw', isa => 'Num',);
+    has 'colour'       => (is => 'rw', isa => 'Str',);
 
 =cut
 
-has 'type_name'    => (is => 'rw', isa => enum(['bar', 'bar_filled', 'pie']), required => 1);
+has 'type_name'    => (is => 'rw', isa => enum(['bar', 'bar_filled', 'pie', 'hbar']), required => 1);
 has 'values'       => (is => 'rw', isa => 'ArrayRef', trigger => sub { $_[0]->extremes->reset('y' => $_[1]); } );
 has 'extremes'     => (is => 'rw', isa => 'Chart-OFC2-Extremes',  default => sub { Chart::OFC2::Extremes->new() }, lazy => 1);
-has 'use_extremes' => (is => 'rw', isa => 'Bool',  default => 1 );
+has 'use_extremes' => (is => 'rw', isa => 'Bool',);
 has 'on-click'     => (is => 'rw', isa => 'Str', );
+has 'tip'          => (is => 'rw', isa => 'Str',);
+has 'alpha'        => (is => 'rw', isa => 'Num',);
+has 'colour'       => (is => 'rw', isa => 'Str',);
 
 
 =head1 METHODS
