@@ -15,7 +15,7 @@ Chart::OFC2::Labels - OFC2 labels object
     'x_axis' => Chart::OFC2::XAxis->new(
         'labels' => Chart::OFC2::Labels->new(
             'labels' => [ 'Jan', 'Feb', 'Mar', 'Apr', 'May', 'Jun' ],
-            'color'  => '#555555'
+            'colour' => '#555555'
         ),
     ),
 
@@ -39,12 +39,12 @@ coerce 'Chart-OFC2-Labels'
 =head1 PROPERTIES
 
     has 'labels' => ( is => 'rw', isa => 'ArrayRef', );
-    has 'color'  => ( is => 'rw', isa => 'Str',  );
+    has 'colour' => ( is => 'rw', isa => 'Str',  );
 
 =cut
 
 has 'labels' => ( is => 'rw', isa => 'ArrayRef', );
-has 'color'  => ( is => 'rw', isa => 'Str',  );
+has 'colour' => ( is => 'rw', isa => 'Str',  );
 
 
 =head1 METHODS
@@ -62,10 +62,15 @@ Returns HashRef that is possible to give to C<encode_json()> function.
 sub TO_JSON {
     my ($self) = @_;
     
-    return {
-        map  { my $v = $self->$_; (defined $v ? ($_ => $v) : ()) }
-        map  { $_->name } $self->meta->compute_all_applicable_attributes
-    };
+    if (defined $self->colour) {
+        return {
+            map  { my $v = $self->$_; (defined $v ? ($_ => $v) : ()) }
+            map  { $_->name } $self->meta->compute_all_applicable_attributes
+        };
+    }
+    else {
+        return [ @{$self->labels} ];
+    }
 }
 
 1;
