@@ -39,7 +39,6 @@ Chart::OFC2::Pie - OFC2 Pie chart
 =cut
 
 use Moose;
-use MooseX::StrictConstructor;
 
 our $VERSION = '0.01';
 
@@ -57,7 +56,7 @@ has 'border'        => (is => 'rw', isa => 'Str',);
 has 'animate'       => (is => 'rw', isa => 'Bool',);
 has 'start-angle'   => (is => 'rw', isa => 'Int',);
 has 'gradient-fill' => (is => 'rw', isa => 'Bool',);
-has 'values'        => (is => 'rw', isa => 'Chart.OFC2.PieValues', 'coerce' => 1,);
+has 'values'        => (is => 'rw', isa => 'Chart-OFC2-PieValues', 'coerce' => 1,);
 
 override 'TO_JSON' => sub {
     my $self = shift;
