@@ -4,37 +4,33 @@ package Chart::OFC2::Scatter;
 
 Chart::OFC2::Scatter - OFC2 Scatter chart
 
-=head1 DESCRIPTION
+=head1 NOT IMPLEMENTED JET
 
-	extends 'Chart::OFC2::Element';
+TBD
 
-=cut
+=begin skip
 
-use Moose;
-use MooseX::StrictConstructor;
+our @ISA = qw(element);
 
-our $VERSION = '0.01';
+sub new() {
+    my ($proto) = @_;
+    my $class = ref($proto) || $proto;
+    my $self = {};
+    bless $self, $class;
+    $self                              = $self->SUPER::new();
+    $self->{'use_extremes'}            = 1;                   # scatter needs x-y min-maxes to print
+    $self->{'element_props'}->{'type'} = __PACKAGE__;
+    $self->{'element_props'}->{'values'} = [
+        { "x" => -5,  "y" => -5 },
+        { "x" => 0,   "y" => 0 },
+        { "x" => 5,   "y" => 5, "dot-size" => 20 },
+        { "x" => 5,   "y" => -5, "dot-size" => 5 },
+        { "x" => -5,  "y" => 5, "dot-size" => 5 },
+        { "x" => 0.5, "y" => 1, "dot-size" => 15 }
+    ];
 
-extends 'Chart::OFC2::Element';
-
-=head1 PROPERTIES
-
-	has '+type_name' => (default => 'scatter');
-
-=cut
-
-has '+type_name'    => (default => 'scatter');
-has '+use_extremes' => (default => 1);    # scatter needs x-y min-maxes to print
-has '+extremes'     => (default => sub { $_[0]->set_extremes }, lazy => 1 );    # scatter needs x-y min-maxes to print
-
-
-=head1 METHODS
-
-=head2 set_extremes()
-
-Set the chart element extremes.
-
-=cut
+    return $self;
+}
 
 sub set_extremes {
     my ($self) = @_;
@@ -45,7 +41,7 @@ sub set_extremes {
         'y_axis_min' => undef,
         'other'      => undef
     };
-    for (@{ $self->values }) {
+    for (@{ $self->{'element_props'}->{'values'} }) {
         $extremes->{'y_axis_max'} = $_->{'y'} if !defined($extremes->{'y_axis_max'});
         if ($_->{'y'} > $extremes->{'y_axis_max'}) {
             $extremes->{'y_axis_max'} = $_->{'y'};
@@ -65,7 +61,9 @@ sub set_extremes {
         }
 
     }
-    $self->extremes(Chart::OFC2::Extremes->new($extremes));
+    $self->{'extremes'} = $extremes;
 }
 
+=cut
+
 1;
